# ApiTestEz

#### 介绍
Make api test easier.

#### 软件架构
软件架构说明


#### 安装教程

1.  xxxx
2.  xxxx
3.  xxxx

#### 使用说明

1.  xxxx
2.  xxxx
3.  xxxx

#### 参与贡献

1.  Fork 本仓库
2.  新建 Feat_xxx 分支
3.  提交代码
4.  新建 Pull Request


#### 特技

1.  使用 Readme\_XXX.md 来支持不同的语言，例如 Readme\_en.md, Readme\_zh.md


#### TODO
1.  用例支持入参，例：f"{'X-Forwarded-For': ${province_ip} }"
2.  url拆分host + path
3.  报告
4.  ORM响应断言实现
5.  cmdline
6.  项目构建工具：ez create xxxx
7.  项目环境构建工具
8.  基于pytest的用例实现

9.  pypi setup
10. 完善注释，文档